pub struct HotkeyActCache { /* private fields */ }Expand description
Maps hotkeys to Acts
This is a trie of hotkeys for better performance and it is only updated when acts with hotkeys are added or removed.
Implementations
Sourceimpl HotkeyActCache
impl HotkeyActCache
Sourcepub fn trie<'a>(
&mut self,
acts: impl Iterator<Item = (Entity, &'a Act)>,
) -> &Trie<KeyChord, ActRef>
pub fn trie<'a>( &mut self, acts: impl Iterator<Item = (Entity, &'a Act)>, ) -> &Trie<KeyChord, ActRef>
Retrieve the cached trie without iterating through acts. Or if
the cache has been invalidated, build and cache a new trie using the
acts iterator.
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Invalidate the cache.